Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(362)

Unified Diff: chrome/test/data/webrtc/getusermedia.js

Issue 1175443002: Revert of Convert the WebRtcTestBase to use infobar and bubble autoresponders (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/push_messaging/push_messaging_browsertest.cc ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/test/data/webrtc/getusermedia.js
diff --git a/chrome/test/data/webrtc/getusermedia.js b/chrome/test/data/webrtc/getusermedia.js
index 20d26028f068779af6b2cbfde8e3d419d439bd91..b1af4944553918ceea8262b6929253db6bc5fc64 100644
--- a/chrome/test/data/webrtc/getusermedia.js
+++ b/chrome/test/data/webrtc/getusermedia.js
@@ -39,11 +39,11 @@
};
/**
* This function asks permission to use the webcam and mic from the browser.
* Its callbacks will return either request-callback-granted or
* request-callback-denied depending on the outcome. If the caller does not
* successfully resolve the request by granting or denying, the test will hang.
* To verify which callback was called, use obtainGetUserMediaResult().
*
* @param {!object} constraints Defines what to be requested, with mandatory
* and optional constraints defined. The contents of this parameter depends
@@ -62,6 +62,7 @@
getUserMediaOkCallback_(stream);
},
getUserMediaFailedCallback_);
+ returnToTest('ok-requested');
}
/**
@@ -155,8 +156,6 @@
gRequestWebcamAndMicrophoneResult = 'ok-got-stream';
attachMediaStream($('local-view'), stream);
-
- returnToTest('request-callback-granted');
}
/**
@@ -170,6 +169,4 @@
debug('GetUserMedia FAILED: Maybe the camera is in use by another process?');
gRequestWebcamAndMicrophoneResult = 'failed-with-error-' + errorName;
debug(gRequestWebcamAndMicrophoneResult);
-
- returnToTest('request-callback-denied');
}
« no previous file with comments | « chrome/browser/push_messaging/push_messaging_browsertest.cc ('k') | no next file » | no next file with comments »
@@ -39,11 +39,11 @@
};
/**
- * This function asks permission to use the webcam and mic from the browser.
- * Its callbacks will return either request-callback-granted or
- * request-callback-denied depending on the outcome. If the caller does not
- * successfully resolve the request by granting or denying, the test will hang.
- * To verify which callback was called, use obtainGetUserMediaResult().
+ * This function asks permission to use the webcam and mic from the browser. It
+ * will return ok-requested to the test. This does not mean the request was
+ * approved though. The test will then have to click past the dialog that
+ * appears in Chrome, which will run either the OK or failed callback as a
+ * a result. To see which callback was called, use obtainGetUserMediaResult().
*
* @param {!object} constraints Defines what to be requested, with mandatory

Powered by Google App Engine
This is Rietveld 408576698